package no.fjas.wspv.axis2;

import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;

import no.fjas.wspv.ConfigParser;
import no.fjas.wspv.Constants;
import no.fjas.wspv.ServiceConfig;
import no.fjas.wspv.util.ClassLoaderUtil;
import no.fjas.wspv.ValidatorSupport;

import org.apache.axiom.soap.SOAPEnvelope;
import org.apache.axis2.AxisFault;
import org.apache.axis2.context.MessageContext;
import org.apache.axis2.engine.Handler;
import org.apache.axis2.handlers.AbstractHandler;
import org.apache.axis2.saaj.util.SAAJUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.w3c.dom.Document;

/**
 * This handler connects Axis2 to WSPV. 
 * Policy configuration is loaded from META-INF/wspv/validation.xml
 *
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 */
public class WSPVHandler extends AbstractHandler {

	protected static Log log = LogFactory.getLog(WSPVHandler.class.getName());

	private Map<String, ServiceConfig> globalServiceConfig = new HashMap<String, ServiceConfig>();

	public WSPVHandler() {
		super();
		loadConfiguration();
	}

	public WSPVHandler(String configurationFile) {
		super();
		loadConfiguration(configurationFile);
	}

	private void loadConfiguration() {
		loadConfiguration(Constants.DEFAULT_CONFIGURATION_FILE);
	}

	private void loadConfiguration(String configurationFile) {

		InputStream is = ClassLoaderUtil.getResourceAsStream(configurationFile,
				WSPVHandler.class);
		if (is != null) {
			globalServiceConfig = ConfigParser.parseValidatorConfigs(is,
					configurationFile);
		} else {
			if (log.isWarnEnabled())
				log.warn("Validation configuration not loaded, config file not found.");
		}
	}

	public InvocationResponse invoke(MessageContext context) throws AxisFault {
		try {
			SOAPEnvelope envelope = context.getEnvelope();
		
			Document doc = SAAJUtil.getDocumentFromSOAPEnvelope(envelope);
			String serviceName = context.getAxisService().getName();

			ServiceConfig serviceConfig = globalServiceConfig.get(serviceName);
			if (serviceConfig != null) {
				if (log.isDebugEnabled())
					log.debug("Service configuration found for service: " + serviceName);

				ValidatorSupport.validateEnvelope(serviceConfig, doc);
			} else {
				if (log.isWarnEnabled())
					log.warn("No validation configuration exists for service: "	+ serviceName);
			}
		} catch (Exception e) {
			log.error("Invoking WSPVHandler failed: " + e.getMessage());
			e.printStackTrace();
			throw new AxisFault(e.getMessage(),e);
		}

		return Handler.InvocationResponse.CONTINUE;
	}

}
