/**
 * 
 */
package no.fjas.wspv;

import java.util.HashMap;
import java.util.Map;

/**
 * Holds the the configuration for a single Service. Consists of a
 * {@link java.util.Map} where the key is built up by
 * ServiceName/OperationName/ParameterName. The value is a Validator that has
 * been initialized with the values from the configuration file. E.g.
 * BookService/findBook/isbn will return a RegexValidator with a regular
 * expression for validating ISBN-numbers.
 * 
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a> 
 */
public class ServiceConfig {
	private String name;
	private boolean validateEverything = false;

	/** The Map containing all validators, the key is Service/Operation/Parameter */
	private Map<String, Validator> validators = new HashMap<String, Validator>();
	
	public boolean isValidateEverything() {
		return validateEverything;
	}

	public void setValidateEverything(boolean mustValidateEverything) {
		this.validateEverything = mustValidateEverything;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Map<String, Validator> getValidators() {
		return validators;
	}

	/**
	 * Adds a validator to the configuration object.  
	 * @param key The key must be on the form: Service/Operation/Parameter.
	 * @param validator The validator to validate the specified parameter.
	 */
	public void addValidator(String key, Validator validator) {
		validators.put(key, validator);
	}

}
