package no.fjas.wspv;

import org.w3c.dom.Element;

/**
 * Validates an SOAP-envelope. The {@link validate} method is called upon
 * invocation of the validation from a SOAP framework handler. Through the
 * {@link addParameter} method, parameters can adjust the behaviour of the
 * validator.
 * 
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 * @version $Id: Validator.java 55 2007-03-14 10:25:48Z henjens $
 */
public interface Validator {

	/**
	 * Performs validation on the given {@link org.w3c.dom.Element}. Fetches
	 * node name and text content from the element.
	 * 
	 * @param element
	 *            the element to validate
	 * @throws ValidationException
	 *             when validation fails
	 */
	void validate(Element element) throws ValidationException;

	/**
	 * Sets parameters to configure a validator
	 * 
	 * @param key
	 *            the name of the parameter to set
	 * @param value
	 *            the value of the parameter to set
	 * @throws ValidatorException
	 *             on invalid parameters. Unknown parameters does not throw an
	 *             exception only a log warning.
	 */
	void addParameter(String key, String value) throws ValidatorException;
}
