package no.fjas.wspv.validators;

/**
 * EmailValidator checks that a given String, if not empty, is a valid email
 * address.
 * 
 * <p>type name = <strong>email</strong></p>
 * 
 * <p>
 * The regular expression used to validate that the string is an email address
 * is:
 * </p>
 * 
 * <pre>
 *  \\b(&circ;[_A-Za-z0-9-]+(\\.[_A-Za-z0-9-]+)*@([A-Za-z0-9-])+(\\.[A-Za-z0-9-]+)*((\\.[A-Za-z0-9]{2,})|(\\.[A-Za-z0-9]{2,}\\.[A-Za-z0-9]{2,}))$)\\b
 * </pre>
 * 
 * <p>
 * Parameters accepted:
 * <ul>
 * <li>-none-</li>
 * </ul>
 * 
 * <em>Original class from OpenSymphony XWork, modified for use in WSPV.</em>
 * </p>
 * 
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 */
public class EmailValidator extends RegexValidator {

	public static final String emailAddressPattern = "\\b(^[_A-Za-z0-9-]+(\\.[_A-Za-z0-9-]+)*@([A-Za-z0-9-])+(\\.[A-Za-z0-9-]+)*((\\.[A-Za-z0-9]{2,})|(\\.[A-Za-z0-9]{2,}\\.[A-Za-z0-9]{2,}))$)\\b";

	public EmailValidator() {
		setExpression(emailAddressPattern);
		setCaseSensitive(false);
	}

}