package no.fjas.wspv.validators;

import java.util.HashMap;
import java.util.Map;

import no.fjas.wspv.ValidationException;
import no.fjas.wspv.Validator;
import no.fjas.wspv.ValidatorException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.w3c.dom.Element;

/**
 * Validator that can validate enums, i.e. predefined strings. 
 * 
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 */
public class EnumValidator implements Validator {

	private static Log log = LogFactory.getLog(EnumValidator.class);
	
	Map<String,Boolean> constants = new HashMap<String,Boolean>();

	private final static String PARAM_CONSTANT = "constant";
	
	/* (non-Javadoc)
	 * @see no.fjas.wspv.Validator#addParameter(java.lang.String, java.lang.String)
	 */
	public void addParameter(String key, String value)
			throws ValidatorException {
		
		if (key == null || key.equals("") || value == null || value.equals(""))
			throw new ValidatorException("Invalid parameter");
		
		if (key.equals(PARAM_CONSTANT)) {
			constants.put(value, Boolean.TRUE);			
		} else {
			if (log.isWarnEnabled())
				log.warn("Ignoring unrecognized parameter " + key);
		}
	}

	/* (non-Javadoc)
	 * @see no.fjas.wspv.Validator#validate(org.w3c.dom.Element)
	 */
	public void validate(Element element) throws ValidationException {
		String value = element.getTextContent();
		
		if (value == null) {
			if (log.isDebugEnabled())
				log.debug("Invalid value, null");
			throw new ValidationException("Invalid value");	
		}
		
		if (value.equals("")) {
			if (log.isDebugEnabled())
				log.debug("Invalid value, empty");			
			throw new ValidationException("Invalid value");
		}
		
		Boolean constant = constants.get(value);
		if (constant == null) {
			if (log.isDebugEnabled())
				log.debug("Invalid value '" + value +"', no match in list: " + constants.keySet().toArray());
			throw new ValidationException("Invalid value");
		}
	}

}
