package no.fjas.wspv.validators;

import java.net.MalformedURLException;
import java.net.URL;

import no.fjas.wspv.ValidationException;
import no.fjas.wspv.Validator;
import no.fjas.wspv.ValidatorException;

import org.w3c.dom.Element;

/**
 * 
 * URLValidator checks that a given String is a valid URL.
 * 
 * <p>type name = <strong>url</strong></p>
 * 
 * <p>
 * Parameters accepted:
 * <ul>
 * <li>-none-</li>
 * </ul>
 *  
 * <em>Original class from OpenSymphony XWork, modified for use in WSPV.</em>
 * </p>
 * 
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 */
public class URLValidator implements Validator {

	/*
	 * (non-Javadoc)
	 * 
	 * @see no.fjas.wspv.Validator#addParameter(java.lang.String,
	 *      java.lang.String)
	 */
	public void addParameter(String key, String value)
			throws ValidatorException {

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see no.fjas.wspv.Validator#validate(org.w3c.dom.Element)
	 */
	public void validate(Element element) throws ValidationException {
		String value = element.getTextContent();

		if (value == null)
			throw new ValidationException("Invalid value");

		if (value.equals("")) {
			throw new ValidationException("Invalid value");
		}

		if (value.startsWith("https://")) {
			// URL doesn't understand the https protocol, hack it
			value = "http://" + value.substring(8);
		}

		try {
			new URL(value);
		} catch (MalformedURLException e) {
			throw new ValidationException("Invalid value", e);
		}
	}
}
