package no.fjas.wspv;

import java.io.InputStream;
import java.util.Map;

import junit.framework.TestCase;
import no.fjas.wspv.ConfigParser;
import no.fjas.wspv.ServiceConfig;
import no.fjas.wspv.Validator;
import no.fjas.wspv.util.ClassLoaderUtil;
import no.fjas.wspv.validators.DateRangeValidator;
import no.fjas.wspv.validators.DoubleRangeValidator;
import no.fjas.wspv.validators.EmailValidator;
import no.fjas.wspv.validators.EnumValidator;
import no.fjas.wspv.validators.IntRangeValidator;
import no.fjas.wspv.validators.LicensePlateNoValidator;
import no.fjas.wspv.validators.MultiPartValidator;
import no.fjas.wspv.validators.RegexValidator;
import no.fjas.wspv.validators.StringLengthValidator;
import no.fjas.wspv.validators.URLValidator;

/**
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 *
 */
public class ConfigParserTest extends TestCase {
		
	private static final String testFileName = "configurations/validator-test.xml";

	public void testLoadDefaultValidators() {
		Validator intValidator = ConfigParser.lookupValidator("int");
		Validator stringValidator = ConfigParser.lookupValidator("string");
		Validator regexValidator = ConfigParser.lookupValidator("regex");
		Validator emailValidator = ConfigParser.lookupValidator("email");
		Validator urlValidator = ConfigParser.lookupValidator("url");
		Validator doubleValidator = ConfigParser.lookupValidator("double");
		Validator dateValidator = ConfigParser.lookupValidator("date");
		Validator multipartValidator = ConfigParser.lookupValidator("multipart");
		Validator enumValidator = ConfigParser.lookupValidator("enum");
		
		assertNotNull(intValidator);
		assertEquals(intValidator.getClass(), IntRangeValidator.class);

		assertNotNull(stringValidator);
		assertEquals(stringValidator.getClass(), StringLengthValidator.class);
		
		assertNotNull(regexValidator);
		assertEquals(regexValidator.getClass(), RegexValidator.class);
		
		assertNotNull(emailValidator);
		assertEquals(emailValidator.getClass(), EmailValidator.class);
		
		assertNotNull(urlValidator);
		assertEquals(urlValidator.getClass(), URLValidator.class);
		
		assertNotNull(doubleValidator);
		assertEquals(doubleValidator.getClass(), DoubleRangeValidator.class);
		
		assertNotNull(dateValidator);
		assertEquals(dateValidator.getClass(), DateRangeValidator.class);
		
		assertNotNull(multipartValidator);
		assertEquals(multipartValidator.getClass(), MultiPartValidator.class);
		
		assertNotNull(enumValidator);
		assertEquals(enumValidator.getClass(), EnumValidator.class);
	}
	
	public void testLoadCustomValidator() {
		Validator validator = ConfigParser.lookupValidator("licenseplate_no");
		
		assertNotNull(validator);
		assertEquals(validator.getClass(), LicensePlateNoValidator.class);
	}
	
	public void testCorrectConfiguration() {
		InputStream is = ClassLoaderUtil.getResourceAsStream(testFileName, this.getClass());
		
		Map<String, ServiceConfig> configurations = ConfigParser.parseValidatorConfigs(is, testFileName);

		assertNotNull(configurations);
		ServiceConfig bookConfig = configurations.get("BookService");
		assertNotNull(bookConfig);
		
		assertTrue(bookConfig.isValidateEverything());
		
		Map<String, Validator> bookValidators = bookConfig.getValidators();
		assertNotNull(bookValidators);
		
		Validator isbnValidator = bookValidators.get("BookService/findBook/isbn");
		assertNotNull(isbnValidator);
	
		assertEquals(RegexValidator.class, isbnValidator.getClass());
		
		Validator addBookValidator = bookValidators.get("BookService/addBook/in0");
		assertNotNull(addBookValidator);
		assertEquals(addBookValidator.getClass(), MultiPartValidator.class);
		
		Validator enumValidator = bookValidators.get("BookService/findBookByType/in0");
		assertNotNull(enumValidator);
		assertEquals(enumValidator.getClass(), EnumValidator.class);
		
		
	}	
}