package no.fjas.wspv;

import java.io.InputStream;
import java.util.Map;

import junit.framework.TestCase;
import no.fjas.wspv.ConfigParser;
import no.fjas.wspv.Constants;
import no.fjas.wspv.ServiceConfig;
import no.fjas.wspv.ValidationException;
import no.fjas.wspv.ValidatorSupport;
import no.fjas.wspv.util.ClassLoaderUtil;
import no.fjas.wspv.util.DomHelper;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;

/**
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 * 
 */
public class ValidatorSupportTest extends TestCase {

	protected Log log = LogFactory.getLog(ValidatorSupportTest.class);

	Map<String, ServiceConfig> config;

	/*
	 * (non-Javadoc)
	 * 
	 * @see junit.framework.TestCase#setUp()
	 */
	protected void setUp() throws Exception {
		InputStream inStream = ClassLoaderUtil.getResourceAsStream(Constants.DEFAULT_CONFIGURATION_FILE,
				ValidatorSupportTest.class);
		config = ConfigParser.parseValidatorConfigs(inStream, "validation.xml");
	}

	public void testValidateSimpleEnvelope() {
		Document request = createDocFromFile("soap_requests/request-addBook_nowhitespace.xml");

		validateEnvelopeSuccess(request);

	}

	public void testEnvelopeWithEnum() {
		Document request = createDocFromFile("soap_requests/request-findBookByType-success.xml");
		validateEnvelopeSuccess(request);
	}

	public void testEnvelopeWithUndefinedEnum() {
		Document request = createDocFromFile("soap_requests/request-findBookByType-failure.xml");
		validateEnvelopeFail(request);
	}
	
	public void testEnvelopeWithUndefinedValidator() {
		Document request = createDocFromFile("soap_requests/request-undefinedValidator.xml");
		ServiceConfig validationConfig = config.get("BookService");
		assertNotNull(validationConfig);
		assertTrue(validationConfig.isValidateEverything());
		
		validateEnvelopeFail(request);
	}
	
	public void testEnvelopeWithComplexMultipartElement() {
		Document request = createDocFromFile("soap_requests/request-addComplexBook-success.xml");
		validateEnvelopeSuccess(request);
	}
	
	public void testEnvelopeWithComplexMultipartElementShouldFail() {
		Document request = createDocFromFile("soap_requests/request-addComplexBook-failure.xml");
		validateEnvelopeFail(request);
	}
	
	/**
	 * Helper method for validating soap envelopes 
	 * @param request
	 */
	private void validateEnvelopeSuccess(Document request) {
		ServiceConfig validationConfig = config.get("BookService");
		assertNotNull(validationConfig);
		
		try {
			ValidatorSupport.validateEnvelope(validationConfig, request);
			assertTrue(true);
		} catch (ValidationException e) {
//			e.printStackTrace();
			fail(e.getMessage());
		}
	}
	
	private void validateEnvelopeFail(Document request) {
		ServiceConfig validationConfig = config.get("BookService");
		assertNotNull(validationConfig);
		
		try {
			ValidatorSupport.validateEnvelope(validationConfig, request);
			
			log.debug("validation finished, we should not be here");
			fail();
		} catch (ValidationException e) {
			e.printStackTrace();
			assertTrue(true);
//			assertEquals(e.getMessage(), "Invalid value");
		}
	}

	/**
	 * Helper method for easily create a {@link org.w3c.dom.Document} from a XML
	 * file.
	 * 
	 * @param filename
	 */
	private Document createDocFromFile(String filename) {
		InputSource inSource = new InputSource(ClassLoaderUtil
				.getResourceAsStream(filename, ValidatorSupportTest.class));
		return DomHelper.parse(inSource);
	}

}
