/**
 * 
 */
package no.fjas.wspv.validators;

import no.fjas.wspv.ValidationException;
import no.fjas.wspv.ValidatorException;
import no.fjas.wspv.validators.DateRangeValidator;

/**
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 *
 */
public class DateValidatorTest extends AbstractValidatorTest {

	public void setUp() {
		super.setUp();
		validator = new DateRangeValidator();
	}
	
	public void testNullParameter() {
		super.testNullParameter();
		try {
			validator.addParameter("dateFormat", null);
			mockupElement.setTextContent("50.00");
			validator.validate(mockupElement);
			fail();
		} catch (ValidatorException e) {
			assertTrue(true);
		} catch (ValidationException e) {
			
		}
	}
	//yyyy.MM.dd
	
	public void testValidDate() {
		try {			
			mockupElement.setTextContent("2007.01.01");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			fail();
		}
	}
	
	public void testValidDateWithCustomDateFormat() {
		try {			
			validator.addParameter("dateFormat", "dd-MM-yyyy");
			mockupElement.setTextContent("01-01-2007");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			fail();
		}
	}
	
	public void testInvalidDateWithCustomDateFormat() {
		try {			
			validator.addParameter("dateFormat", "dd-MM-yyyy");
			mockupElement.setTextContent("2007.01.01");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
	
	public void testInvalidDate() {
		try {			
			mockupElement.setTextContent("2007.AA01.01");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
	
	public void testMinExclusiveSuccess() {
		try {			
			validator.addParameter("minExclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.16");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
	}
	
	public void testMinExclusiveFail() {
		try {			
			validator.addParameter("minExclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.15");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
		
		try {			
			validator.addParameter("minExclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.14");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
	
	public void testMaxExclusiveSuccess() {
		try {			
			validator.addParameter("maxExclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.14");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
	}
	
	public void testMaxExclusiveFail() {
		try {			
			validator.addParameter("maxExclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.15");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
		
		try {			
			validator.addParameter("maxExclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.16");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
	
	public void testMinInclusiveSuccess() {
		try {			
			validator.addParameter("minInclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.15");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
		
		try {			
			validator.addParameter("minInclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.16");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
	}
	
	public void testMinInclusiveFail() {
		try {			
			validator.addParameter("minInclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.14");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
	
	public void testMaxInclusiveSuccess() {
		try {			
			validator.addParameter("maxInclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.15");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
		
		try {			
			validator.addParameter("maxInclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.14");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
	}
	
	public void testMaxInclusiveFail() {
		try {			
			validator.addParameter("maxInclusive", "2007.01.15");
			mockupElement.setTextContent("2007.01.16");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
}
