/**
 * 
 */
package no.fjas.wspv.validators;

import no.fjas.wspv.ValidationException;
import no.fjas.wspv.ValidatorException;
import no.fjas.wspv.validators.DoubleRangeValidator;

/**
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 *
 */
public class DoubleValidatorTest extends AbstractValidatorTest {
	
	public void setUp() {
		super.setUp();
		validator = new DoubleRangeValidator();
	}
	
	public void testValidValue() {
		try {
			mockupElement.setTextContent("49.99");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			fail();
		}
	}
	
	public void testInvalidValue() {
		try {
			mockupElement.setTextContent("A200.200");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}
	}
	
	public void testNullParameter() {
		super.testNullParameter();
		
		try {
			validator.addParameter("minInclusive", null);
			mockupElement.setTextContent("50.00");
			validator.validate(mockupElement);
			fail();
		} catch (ValidatorException e) {
			assertTrue(true);
		} catch (ValidationException e) {
			
		}
	}
	
	public void testInvalidParameter() {
		try {
			validator.addParameter("minInclusive", "A2002");
			mockupElement.setTextContent("50.00");
			validator.validate(mockupElement);
			fail();
		} catch (ValidatorException e) {
			assertTrue(true);
		} catch (ValidationException e) {
			
		}
	}
	
	public void testMaxInclusiveShouldSuccess() {
		try {
			validator.addParameter("maxInclusive", "50.00");
			mockupElement.setTextContent("50.00");			
			validator.validate(mockupElement);
			mockupElement.setTextContent("49.99");			
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			fail();
		}
	}
	
	public void testMaxInclusiveShouldFail() {
		try {
			validator.addParameter("maxInclusive", "50.00");
			mockupElement.setTextContent("50.01");			
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
	
	public void testMinInclusiveShouldSuccess() {
		try {
			validator.addParameter("minInclusive", "50.00");
			mockupElement.setTextContent("50.00");			
			validator.validate(mockupElement);
			mockupElement.setTextContent("51.00");			
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {		
			fail();
		}
	}
	
	public void testMinInclusiveShouldFail() {
		try {
			validator.addParameter("minInclusive", "50.00");
			mockupElement.setTextContent("49.99");			
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {		
			assertTrue(true);
		}
	}
	
	public void testMaxExclusiveShouldSuccess() {
		try {
			validator.addParameter("maxExclusive", "50.00");
			mockupElement.setTextContent("49.99");			
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
	}
	
	public void testMaxExclusiveShouldFail() {
		try {
			validator.addParameter("maxExclusive", "50.00");
			mockupElement.setTextContent("50.00");			
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}
		
		try {
			validator.addParameter("maxExclusive", "50.00");
			mockupElement.setTextContent("51.00");			
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}
	}
	
	public void testMinExclusiveShouldSuccess() {
		try {
			validator.addParameter("minExclusive", "50.00");
			mockupElement.setTextContent("50.01");			
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}
	}
	
	public void testMinExclusiveShouldFail() {
		try {
			validator.addParameter("minExclusive", "50.00");
			mockupElement.setTextContent("50.00");			
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {		
			assertTrue(true);
		}
		
		try {
			validator.addParameter("minExclusive", "50.00");
			mockupElement.setTextContent("49.00");			
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {		
			assertTrue(true);
		}
	}
}
