package no.fjas.wspv.validators;

import no.fjas.wspv.ValidationException;
import no.fjas.wspv.ValidatorException;
import no.fjas.wspv.validators.IntRangeValidator;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class IntRangeFieldValidatorTest extends AbstractValidatorTest {
	
	static Log log = LogFactory.getLog(IntRangeFieldValidatorTest.class);
	
	public void setUp() {
		super.setUp();
		validator  = new IntRangeValidator();
	}
	
	public void testValidInt() {
		try {
			mockupElement.setTextContent("1");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			fail();
		}
	}
	
	public void testInvalidInt() {
		try {
			mockupElement.setTextContent("1A");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
	}
	
	public void testNullParameter() {
		super.testNullParameter();
		
		try {
			validator.addParameter("maxInclusive", null);
			fail();
		} catch (ValidatorException e) {
			assertTrue(true);
		}
	}
	
	
	public void testMaxExclusiveShouldThrowException() {
		try {
			validator.addParameter("maxExclusive", "100");
			mockupElement.setTextContent("100");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}	
		
		try {
			mockupElement.setTextContent("101");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}	
	}
	
	public void testMaxExclusiveShouldPass() {
		validator.addParameter("maxExclusive", "100");
		
		try {
			mockupElement.setTextContent("99");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {			
			fail();
		}	
	}
	
	
	public void testMinExclusiveShouldThrowException() {
		validator.addParameter("minExclusive", "100");
		
		try {
			mockupElement.setTextContent("100");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}
		
		try {
			mockupElement.setTextContent("99");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {			
			assertTrue(true);
		}	
	}
	
	public void testMinExclusiveShouldPass() {
		validator.addParameter("minExclusive", "100");
		
		try {
			mockupElement.setTextContent("101");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			fail();
		}
	}
	
	
	public void testMaxInclusiveShouldThrowException() {
		validator.addParameter("maxInclusive", "100");
		
		try {
			mockupElement.setTextContent("101");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}		
	}
	
	public void testMaxInclusiveShouldPass() {
		validator.addParameter("maxInclusive", "100");
		
		try {
			mockupElement.setTextContent("100");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			e.printStackTrace();
			fail();
		}
		
		try {
			mockupElement.setTextContent("99");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			e.printStackTrace();
			fail();
		}	
	}
		
	public void testMinInclusiveShouldThrowException() {
		validator.addParameter("minInclusive", "100");
		
		try {
			mockupElement.setTextContent("99");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}
	}
	
	public void testMinInclusiveShouldPass() {
		validator.addParameter("minInclusive", "100");;
		
		try {
			mockupElement.setTextContent("100");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			e.printStackTrace();
			fail();
		}
		
		try {
			mockupElement.setTextContent("101");
			validator.validate(mockupElement);
			assertTrue(true);
		} catch (ValidationException e) {
			fail();
		}		
	}
}