package no.fjas.wspv.validators;

import junit.framework.TestCase;
import no.fjas.wspv.ValidationException;
import no.fjas.wspv.validators.URLValidator;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 *
 */
public class URLValidatorTest extends TestCase {

	URLValidator validator = null;
	Element mockupElement = null;
	
	public void setUp() {
		Document doc = new org.apache.xerces.dom.CoreDocumentImpl();
		mockupElement = doc.createElement("test");

		validator = new URLValidator();
	}
	
	
	public void testHttpsUrl() {
		try {
			mockupElement.setTextContent("https://henning.fjas.no/validator/index.html");
			validator.validate(mockupElement);
		} catch (ValidationException e) {
			fail(e.getMessage());
		}
	}
	
	public void testEmptyURL() {
		try {
			mockupElement.setTextContent("");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}
	}
	
	public void testWeirdButLegalUrl() {
		try {
			mockupElement.setTextContent("http://www.jroller.com1?qwe=qwe");
			validator.validate(mockupElement);
		} catch (ValidationException e) {
			fail();
		}
	}
		
	public void testLegalUrlWithQueryString() {
		try {
			mockupElement.setTextContent("http://yahoo.com/articles?id=123");
			validator.validate(mockupElement);
		} catch (ValidationException e) {
			fail();
		}
	}

	public void testMissingHttp() {
		try {
			mockupElement.setTextContent("www.yahoo.com/articles?id=123");
			validator.validate(mockupElement);
			fail();
		} catch (ValidationException e) {
			assertTrue(true);
		}
	}	
}
