package no.fjas.wspv.examples.xfire;

import java.net.MalformedURLException;
import java.util.Map;

import org.codehaus.xfire.XFireRuntimeException;
import org.codehaus.xfire.client.Client;
import org.codehaus.xfire.client.XFireProxyFactory;
import org.codehaus.xfire.service.Service;
import org.codehaus.xfire.service.binding.ObjectServiceFactory;

/**
 * @author <a href="mailto:nathanyp@hotmail.com">Nathan Peles</a>
 * @author <a href="mailto:tsztelak@gmail.com">Tomasz Sztelak</a>
 */
public class BookClient {

	public static void main(String args[]) {
		String serviceURL = "http://localhost:8080/xfire-book/services/BookService";
		Service serviceModel = new ObjectServiceFactory().create(
				BookService.class, null,
				"http://wspv.fjas.no/BookService/", null);

		XFireProxyFactory serviceFactory = new XFireProxyFactory();

		try {
			BookService service = (BookService) serviceFactory.create(
					serviceModel, serviceURL);
//
//			invokeGetBooks(service);

			invokeFindBookLegal(service);

			invokeFindBookIllegal(service);
//
//			invokeFindBooksByMaxPriceLegal(service);
//
//			invokeAddBook(service);
//			
//			invokeAddDangerousBook(service);
			
		} catch (MalformedURLException e) {
			e.printStackTrace();
		}

	}

	private static void invokeFindBooksByMaxPriceLegal(BookService service) {
		System.out.println("Invoking findBookByMaxPrice:");
		try {
			Book[] book = service.findBooksByMaxPrice(50.50);

			for (int i = 0; i < book.length; i++) {
				System.out.println("Book found: " + book[i]);
			}
		} catch (XFireRuntimeException e) {
			System.out.println("XFireRuntimeException caught: "
					+ e.getCause().getMessage());
		}
		System.out.println("----");
	}

	/**
	 * @param service
	 */
	private static void invokeFindBookIllegal(BookService service) {
		try {
			System.out.println("Invoking findBook with illegal ISBN:");
			service.findBook("12-3456-789-00");
		} catch (BookException e) {
			System.out.println(e.getFaultInfo().getDetailMessage());
		} catch (XFireRuntimeException e) {
			System.out.println("XFireRuntimeException caught: "
					+ e.getCause().getMessage());
		}
		System.out.println("----");
	}

	/**
	 * @param service
	 */
	private static void invokeFindBookLegal(BookService service) {
		try {
			System.out.println("Invoking findBook with legal ISBN:");
			Book book = service.findBook("12-3456-789-0");
			System.out.println("Book found: " + book);
		} catch (BookException e) {
			System.out.print(e.getFaultInfo().getDetailMessage());
		}
		System.out.println("----");
	}

	/**
	 * @param service
	 */
	private static void invokeGetBooks(BookService service) {
		try {
			System.out.println("----");
			System.out.println("Invoking getBooks():");

			Book[] books = service.getBooks();

			for (int i = 0; i < books.length; i++) {
				System.out.println("Book " + i + ": " + books[i].toString());
			}
			System.out.println("----");
		} catch (RuntimeException e) {
			e.printStackTrace();
		}
	}
	
	private static void invokeAddBook(BookService service) {
		try {
			System.out.println("----");
			System.out.println("Invoking addBook:");
			
			Book book = new Book();
			book.setId(2);
			book.setAuthor("John Doe");
			book.setIsbn("22-3344-556-6");
			book.setPrice(55.99);
			book.setTitle("Web Services in Action");
			
			System.out.println("Adding Book: " + book);
			service.addBook(book);
			
			System.out.println("Checking booklist:");
			
			invokeGetBooks(service);
			
			System.out.println("AddBook finished.");
		} catch (RuntimeException e) {
			e.printStackTrace();
		}
		
	}
	
	private static void invokeAddDangerousBook(BookService service) {
		try {
			System.out.println("----");
			System.out.println("Invoking addBook with dangerous XSS content:");
			
			Book book = new Book();
			book.setId(2);
			book.setAuthor("John Doe<script>alert('ok')</script>");
			book.setIsbn("22-3344-556-6");
			book.setPrice(55.99);
			book.setTitle("Web Services %3C%73%63%72%69%70%74%3Ealert('OK')%3C%2F%73%63%72%69%70%74%3E in Action");
			
			System.out.println("Adding Book: " + book);
			service.addBook(book);
			
			System.out.println("AddBook finished.");
		} catch (RuntimeException e) {
			e.printStackTrace();
		}
		
	}
}