package no.fjas.wspv.xfire;

import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;

import no.fjas.wspv.ConfigParser;
import no.fjas.wspv.Constants;
import no.fjas.wspv.ServiceConfig;
import no.fjas.wspv.ValidatorSupport;
import no.fjas.wspv.util.ClassLoaderUtil;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.codehaus.xfire.MessageContext;
import org.codehaus.xfire.exchange.AbstractMessage;
import org.codehaus.xfire.handler.AbstractHandler;
import org.codehaus.xfire.handler.Phase;
import org.codehaus.xfire.util.dom.DOMInHandler;
import org.w3c.dom.Document;

/**
 * WSPV Handler for XFire.
 * 
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 */
public class WSPVHandler extends AbstractHandler {

	protected static Log log = LogFactory.getLog(WSPVHandler.class
			.getName());

	private Map<String, ServiceConfig> globalServiceConfig = new HashMap<String, ServiceConfig>();

	public WSPVHandler() {
		super();
		loadConfiguration();
	}

	public WSPVHandler(String configurationFile) {
		super();
		loadConfiguration(configurationFile);
	}

	private void loadConfiguration() {
		loadConfiguration(Constants.DEFAULT_CONFIGURATION_FILE);
	}

	@SuppressWarnings("unchecked")
	private void loadConfiguration(String configurationFile) {
		// Make sure handler is in correct phase and after DOMInHandler
		setPhase(Phase.PARSE);
		getAfter().add(DOMInHandler.class.getName());
	
		InputStream is = ClassLoaderUtil.getResourceAsStream(configurationFile,
				WSPVHandler.class);
		if (is != null) {
			globalServiceConfig = ConfigParser.parseValidatorConfigs(is,
					configurationFile);
		} else {
			if (log.isWarnEnabled())
				log.warn("Validation configuration not loaded, config file not found.");
		}
	}

	public void invoke(MessageContext context) throws Exception {
		if (log.isDebugEnabled())
			log.debug("ValidatorInHandler has been invoked");

		String serviceName = context.getService().getName().getLocalPart();
		if (log.isDebugEnabled())
			log.debug("service.name: " + serviceName);

		ServiceConfig serviceConfig = globalServiceConfig.get(serviceName);
		if (serviceConfig != null) {
			if (log.isDebugEnabled())
				log.debug("Service configuration found for service: "
						+ serviceName);

			AbstractMessage currentMessage = context.getInMessage();
			Document doc = (Document) currentMessage
					.getProperty(DOMInHandler.DOM_MESSAGE);

			if (doc == null) {
				log.warn("Incoming message document is null!");
			} else {
				if (log.isDebugEnabled())
					log.debug("Validating document");
				ValidatorSupport.validateEnvelope(serviceConfig, doc);
			}

		} else {
			log.warn("No validation configuration exists for service: "
					+ serviceName);
		}
	}
}
