/**
 * 
 */
package no.fjas.wspv.xfire;

import java.io.InputStream;

import no.fjas.wspv.util.ClassLoaderUtil;
import no.fjas.wspv.xfire.WSPVHandler;
import no.fjas.wspv.xfire.service.BookService;
import no.fjas.wspv.xfire.service.BookServiceImpl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.codehaus.xfire.service.Service;
import org.codehaus.xfire.service.invoker.ObjectInvoker;
import org.codehaus.xfire.soap.Soap11;
import org.codehaus.xfire.test.AbstractXFireTest;
import org.codehaus.xfire.util.STAXUtils;
import org.codehaus.xfire.util.dom.DOMInHandler;
import org.jdom.Document;

/**
 * @author <a href="mailto:henning _at_ fjas.no">Henning Jensen</a>
 * 
 */
public class WSPVHandlerTest extends AbstractXFireTest {

	protected static Log log = LogFactory.getLog(WSPVHandlerTest.class);

	public void setUp() {
		Service service = getServiceFactory().create(BookService.class,
				"BookService", null, null);
		service.setProperty(ObjectInvoker.SERVICE_IMPL_CLASS,
				BookServiceImpl.class);

		service.addInHandler(new DOMInHandler());
		service.addInHandler(new WSPVHandler());

		getServiceRegistry().register(service);
		addNamespace("s", Soap11.getInstance().getNamespace());
	}

	public void testRegexFailure() throws Exception {
		Document response = executeService("BookService",
				"soap_requests/request-fail-regex.xml");

		assertValid("//s:Fault", response);
	}

	public void testRegexSuccess() throws Exception {
		Document response = executeService("BookService",
				"soap_requests/request-success-regex.xml");
		assertInvalid("//s:Fault", response);
	}

	public void testUnparseableIntegerFailure() throws Exception {
		Document response = executeService("BookService",
				"soap_requests/request-fail-integer.xml");

		assertValid("//s:Fault", response);
	}

	public void testOutOfMaxRangeIntegerFailure() throws Exception {
		Document response = executeService("BookService",
				"soap_requests/request-fail-integer2.xml");

		assertValid("//s:Fault", response);
	}

	public void testOutOfMinRangeIntegerFailure() throws Exception {
		Document response = executeService("BookService",
				"soap_requests/request-fail-integer3.xml");

		assertValid("//s:Fault", response);
	}

	public void testInclusiveMinRangeIntegerSuccess() throws Exception {
		Document response = executeService("BookService",
				"soap_requests/request-success-integer.xml");

		assertInvalid("//s:Fault", response);
	}

	public void testInclusiveMaxRangeIntegerSuccess() throws Exception {
		Document response = executeService("BookService",
				"soap_requests/request-success-integer2.xml");

		assertInvalid("//s:Fault", response);
	}

	/**
	 * @param serviceName
	 * @param requestResource
	 * @return
	 * @throws Exception
	 */
	private Document executeService(String serviceName, String requestResource)
			throws Exception {
		InputStream inStream = ClassLoaderUtil.getResourceAsStream(
				requestResource, WSPVHandlerTest.class);
		return invokeService(serviceName, STAXUtils.createXMLStreamReader(
				inStream, "UTF-8", null));
	}
}